@@ -160,7 +160,7 @@ namespace lat
 
 				if (_isEdit) {
 					attrListStore.AppendValues (s, 
-						"Required", 
+						"Optional", 
 						t.GetAttributeDefaultValue (s));
 
 				} else {
@@ -237,7 +237,7 @@ namespace lat
 				string nam = (string) row[0];
 				string val = (string) row[2];
 				
-				if (nam == null || val == null || val == "")
+				if (string.IsNullOrEmpty(nam) || string.IsNullOrEmpty(val))
 					continue;
 					
 				t.AddAttribute (nam, val);
