@@ -20,10 +20,11 @@
 
 using Gtk;
 using System;
-using System.Collections;
+using System.Collections.Generic;
 using System.IO;
 using System.Runtime.InteropServices;
 using System.Text;
+using System.Xml;
 using Mono.Unix;
 using Novell.Directory.Ldap;
 
@@ -35,46 +36,248 @@ namespace lat
 		{
 		}
 
-		// Taken from Banshee; written by Aaron Bockover (aaron@aaronbock.net)
-	        [DllImport("libc")]
-	        static extern int prctl(int option, byte [] arg2, ulong arg3 , ulong arg4, ulong arg5);
+		[DllImport("libc")]
+		static extern int prctl(int option, byte [] arg2, ulong arg3 , ulong arg4, ulong arg5);
         
-        	public static void SetProcessName(string name)
-	        {
-	            if(prctl(15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes(name), 0, 0, 0) != 0) {
-        	        throw new ApplicationException("Error setting process name: " + 
-                	    Mono.Unix.Native.Stdlib.GetLastError());
-	            }
-        	}
-
-		private static LdapModification createMod (string name, string val)
+		public static void SetProcessName(string name)
 		{
-			LdapAttribute la; 
-			LdapModification lm;
-
-			la = new LdapAttribute (name, val);
-			lm = new LdapModification (LdapModification.ADD, la);
-
-			return lm;
+			try {        	
+				if(prctl(15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes(name), 0, 0, 0) != 0) {
+					Log.Debug ("Error setting process name: " + 
+					Mono.Unix.Native.Stdlib.GetLastError());
+				}
+			} catch { }
 		}
 
-		public static string GetServerPrefix (LdapServer server)
+		public static ComboBox CreateServerCombo ()
 		{
-			string prefix = null;
-	
-			switch (server.ServerType) {
+			ComboBox serverComboBox = ComboBox.NewText ();			
+			foreach (string s in Global.Connections.ConnectionNames)
+				serverComboBox.AppendText (s);
 
-			case LdapServerType.ActiveDirectory:
-				prefix = "ad";
-				break;
+			serverComboBox.Active = 0;
+			serverComboBox.Show ();
+			
+			return serverComboBox;
+		}
 
-			case LdapServerType.Generic:
-			case LdapServerType.OpenLDAP:
-				prefix = "openldap";
-				break;
+		public static bool IsOldConfig ()
+		{
+			bool ret = false;
+			string v1Views = Path.Combine (GetConfigDirectory (), "views.xml");
+			
+			if (File.Exists (v1Views))
+				ret = true;
+			
+			return ret;
+		}
+
+		public static void UpgradeConfigurationFiles ()
+		{
+			try {
+				
+				Log.Debug ("Upgrading configuration files from LAT v1.0");
+				
+				string latDir = GetConfigDirectory();
+				
+				File.Delete (Path.Combine (latDir, "templates.dat"));
+				File.Delete (Path.Combine (latDir, "views.xml"));
+				
+				XmlDocument updatedProfiles = ConvertV1Profiles ();
+				updatedProfiles.Save (Path.Combine (latDir, "profiles.xml"));
+				
+				Log.Debug ("Upgrade complete.");
+			
+			} catch (Exception e) {
+				
+				Log.Error ("Unable to upgrade configuration files due to: {0}", e.Message);
+				Log.Debug (e);
+			}
+		}
+
+		static Connection ParseV1Profile (XmlElement profileElement)
+		{
+			EncryptionType e = EncryptionType.None;
+			bool savePassword = false;
+
+			string encryption = profileElement.GetAttribute ("encryption");
+			if (encryption != null) {
+				if (encryption.ToLower() == "ssl")
+					e = EncryptionType.SSL;
+				else if (encryption.ToLower() == "tls")
+					e = EncryptionType.TLS;
 			}
 
-			return prefix;
+			string sp = profileElement.GetAttribute ("save_password");
+			if (sp != null) {
+				try { savePassword = bool.Parse (sp); }
+				catch { savePassword = false; }
+			}
+			
+			ConnectionData data = new ConnectionData (
+					profileElement.GetAttribute ("name"),
+					profileElement.GetAttribute ("host"),
+					int.Parse (profileElement.GetAttribute ("port")),
+					profileElement.GetAttribute ("base"),
+					profileElement.GetAttribute ("user"),
+					savePassword,
+					e,
+					Util.GetServerType (profileElement.GetAttribute ("server_type")),
+					false);
+
+			Connection conn = new Connection (data);
+			conn.SetDefaultAttributeViewers ();
+			conn.SetDefaultServerViews ();			
+					
+			return conn;
+		}
+
+		static XmlDocument ConvertV1Profiles ()
+		{
+			string latDir = GetConfigDirectory ();
+
+			// Create new profiles document			
+			XmlDocument newDoc = new XmlDocument ();
+			newDoc.AppendChild (newDoc.CreateNode (XmlNodeType.XmlDeclaration,"",""));
+			
+			XmlElement profiles = newDoc.CreateElement ("profiles");
+			newDoc.AppendChild (profiles);			
+			
+			// read data from old profiles document
+			XmlDocument oldDoc = new XmlDocument ();
+			oldDoc.Load (Path.Combine (latDir, "profiles.xml"));
+
+			XmlNodeList nl = oldDoc.GetElementsByTagName ("profile");
+			if (!(nl.Count > 0))
+				return null;
+
+			foreach (XmlElement p in nl) {
+				Connection c = ParseV1Profile (p);
+
+				XmlElement profile = newDoc.CreateElement ("profile");
+				profile.SetAttribute ("name", c.Settings.Name);
+				profile.SetAttribute ("host", c.Settings.Host);
+				profile.SetAttribute ("port", c.Settings.Port.ToString());
+				profile.SetAttribute ("base", c.Settings.DirectoryRoot);
+				profile.SetAttribute ("user", c.Settings.UserName);
+				profile.SetAttribute ("save_password", c.Settings.DontSavePassword.ToString());
+				profile.SetAttribute ("encryption", Util.GetEncryptionType (c.Settings.Encryption));
+				profile.SetAttribute ("server_type", Util.GetServerType (c.Settings.ServerType));
+				
+				XmlElement server_views = newDoc.CreateElement ("server_views");
+				foreach (string sv in c.ServerViews) {
+					XmlElement server_view = newDoc.CreateElement ("server_view");
+					server_view.InnerText = sv;
+					server_views.AppendChild (server_view);
+				}				
+				profile.AppendChild (server_views);
+				
+				XmlElement attribute_viewers = newDoc.CreateElement ("attribute_viewers");
+				foreach (string a in c.AttributeViewers) {
+					XmlElement av = newDoc.CreateElement ("attribute_viewer");
+					av.InnerText = a;
+					attribute_viewers.AppendChild (av);
+				}								
+				profile.AppendChild (attribute_viewers);
+				
+				profiles.AppendChild (profile);				
+			}
+			
+			return newDoc;
+		}
+
+		public static string GetConfigDirectory ()
+		{
+			string homeDir = Environment.GetFolderPath(Environment.SpecialFolder.Personal); 
+			string latDir = Path.Combine (homeDir, ".lat");
+			
+			return latDir;
+		}
+
+		public static double GetDateTime (string stringDate)
+		{
+			int ret = 0;
+		
+			try { 
+				DateTime newTime = DateTime.Parse (stringDate);
+				return Util.GetUnixTime (newTime); 
+			} catch {}
+			
+			return ret;				
+		}
+
+		public static DateTime GetDateTime (double unixTime)
+		{
+			DateTime dt = new DateTime (1970, 1, 1, 0, 0, 0, 0);
+			dt = dt.AddSeconds (unixTime);
+			
+			return dt;
+		}
+
+		public static double GetUnixTime (DateTime dt)
+		{
+			TimeSpan ts = dt.Subtract (new DateTime(1970,1,1,0,0,0));
+			return ts.TotalSeconds;
+		}
+
+		public static string GetEncryptionType (EncryptionType encryptionType)
+		{
+			switch (encryptionType) {
+
+			case EncryptionType.TLS:
+				return "tls";
+
+			case EncryptionType.SSL:
+				return "ssl";
+
+			case EncryptionType.None:
+				return "none";
+				
+			default:
+				throw new ArgumentOutOfRangeException ("Invalid encryption type");
+			}		
+		}
+
+		public static LdapServerType GetServerType (string serverType)
+		{
+			switch (serverType.ToLower()) {
+			
+			case "microsoft active directory":
+				return LdapServerType.ActiveDirectory;
+			
+			case "fedora directory server":
+				return LdapServerType.FedoraDirectory;
+			
+			case "generic ldap server":
+				return LdapServerType.Generic;
+			
+			case "openldap":
+				return LdapServerType.OpenLDAP;
+			
+			default:
+				return LdapServerType.Unknown;
+			}
+		}
+
+		public static string GetServerType (LdapServerType serverType)
+		{
+			switch (serverType) {
+			
+			case LdapServerType.ActiveDirectory:
+				return "microsoft active directory";
+				
+			case LdapServerType.FedoraDirectory:
+				return "fedora directory server";
+				
+			case LdapServerType.Generic:
+				return "generic ldap server";
+				
+			case LdapServerType.OpenLDAP:
+				return "openldap";
+				
+			default:
+				return "unknown";								
+			}
 		}
 
 		public static void DisplaySambaSIDWarning (Gtk.Window parent)
@@ -96,23 +299,22 @@ namespace lat
 			dialog.Destroy ();
 		}
 
-		public static ArrayList CreateSambaMods (int uid, string sid, string lm, string nt)
+		public static LdapAttribute[] CreateSambaAttributes (int uid, string sid, string lm, string nt)
 		{
-			ArrayList mods = new ArrayList ();
+			List<LdapAttribute> mods = new List<LdapAttribute> ();
 
-			mods.Add (createMod ("objectclass", "sambaSAMAccount"));
-			mods.Add (createMod ("sambaLMPassword", lm));
-			mods.Add (createMod ("sambaNTPassword", nt));
-			mods.Add (createMod ("sambaAcctFlags", "[U          ]"));
+			mods.Add (new LdapAttribute ("sambaLMPassword", lm));
+			mods.Add (new LdapAttribute ("sambaNTPassword", nt));
+			mods.Add (new LdapAttribute ("sambaAcctFlags", "[U          ]"));
 
 			int user_rid = Convert.ToInt32 (uid) * 2 + 1000;
 
-			mods.Add (createMod ("sambaSID", String.Format ("{0}-{1}", sid, user_rid)));
-			mods.Add (createMod ("sambaPrimaryGroupSID", String.Format ("{0}-513", sid)));
+			mods.Add (new LdapAttribute ("sambaSID", String.Format ("{0}-{1}", sid, user_rid)));
+			mods.Add (new LdapAttribute ("sambaPrimaryGroupSID", String.Format ("{0}-513", sid)));
 			
-			return mods;
+			return mods.ToArray();
 		}
-
+		
 		public static bool CheckSamba (LdapEntry le)
 		{
 			bool retVal = false;
@@ -127,7 +329,7 @@ namespace lat
 					retVal = true;
 
 			return retVal;
-		}
+		}		
 
 		public static string SuggestUserName (string firstName, string lastName)
 		{
@@ -158,104 +360,63 @@ namespace lat
 			return retIcon;
 		}
 
-		public static bool CheckUserName (LdapServer server, string name)
+		public static bool CheckUserName (Connection conn, string name)
 		{
-			if (server.Search(String.Format("(uid={0})", name)).Length == 0)
+			if (conn.Data.Search(String.Format("(uid={0})", name)).Length == 0)
 				return true;
 		
 			return false;
 		}
 
-		public static bool CheckUID (LdapServer server, int uid)
+		public static bool CheckUID (Connection conn, int uid)
 		{
-			if (server.Search(String.Format("(uidNumber={0})", uid)).Length == 0)
+			if (conn.Data.Search(String.Format("(uidNumber={0})", uid)).Length == 0)
 				return true;
 		
 			return false;
 		}
 
-		public static bool AddEntry (LdapServer server, Gtk.Window parent, 
-					     string dn, ArrayList attrs, bool msgBox)
+		public static bool AddEntry (Connection conn, LdapEntry entry)
 		{
 			try {
 
-				server.Add (dn, attrs);
-
-				string resMsg = String.Format (
-					Mono.Unix.Catalog.GetString ("Entry {0} has been added."), dn);
-	
-				if (msgBox) {
-
-					HIGMessageDialog dialog = new HIGMessageDialog (
-						parent,
-						0,
-						Gtk.MessageType.Info,
-						Gtk.ButtonsType.Ok,
-						"Add entry",
-						resMsg);
-
-					dialog.Run ();
-					dialog.Destroy ();
-				}
-
+				conn.Data.Add (entry);
 				return true;
 
 			} catch (Exception e) {
 
-				string errorMsg = 
-					Mono.Unix.Catalog.GetString ("Unable to add entry ") + dn;
-
+				string errorMsg = Mono.Unix.Catalog.GetString ("Unable to add entry ") + entry.DN;
 				errorMsg += "\nError: " + e.Message;
 
-					HIGMessageDialog dialog = new HIGMessageDialog (
-						parent,
+				Log.Debug (e);
+
+				HIGMessageDialog dialog = new HIGMessageDialog (
+						null,
 						0,
 						Gtk.MessageType.Error,
 						Gtk.ButtonsType.Ok,
 						"Add error",
 						errorMsg);
 
-					dialog.Run ();
-					dialog.Destroy ();
+				dialog.Run ();
+				dialog.Destroy ();
 
 				return false;
-			}
+			}		
 		}
 
-		public static bool ModifyEntry (LdapServer server, Gtk.Window parent, 
-						string dn, ArrayList modList, bool msgBox)
+		public static bool ModifyEntry (Connection conn, string dn, LdapModification[] modList)
 		{
-			if (modList.Count == 0) {
-				Logger.Log.Debug ("ModifyEntry: modList.Count == 0");
+			if (modList.Length == 0) {
+				Log.Debug ("No modifications to make to entry {0}", dn);
 				return false;
 			}
 
-			LdapModification[] mods;
-			mods = new LdapModification [modList.Count];
-			mods = (LdapModification[]) modList.ToArray(typeof(LdapModification));
-
 			try {
 
-				server.Modify (dn, mods);
-
-				string resMsg = String.Format (
-					Mono.Unix.Catalog.GetString ("Entry {0} has been modified."), dn);
-
-				if (msgBox) {
-					HIGMessageDialog dialog = new HIGMessageDialog (
-						parent,
-						0,
-						Gtk.MessageType.Info,
-						Gtk.ButtonsType.Ok,
-						"Modify entry",
-						resMsg);
-
-					dialog.Run ();
-					dialog.Destroy ();
-				}
-
-				modList.Clear ();
-
+				conn.Data.Modify (dn, modList);
+				Log.Debug ("Successfully modified entry {0}", dn);
+				
 				return true;
 
 			} catch (Exception e) {
@@ -266,7 +427,7 @@ namespace lat
 				errorMsg += "\nError: " + e.Message;
 
 				HIGMessageDialog dialog = new HIGMessageDialog (
-					parent,
+					null,
 					0,
 					Gtk.MessageType.Error,
 					Gtk.ButtonsType.Ok,
@@ -277,9 +438,9 @@ namespace lat
 				dialog.Destroy ();
 
 				return false;
-			}
+			}		
 		}
-
+		
 		public static bool AskYesNo (Gtk.Window parent, string msg)
 		{
 			MessageDialog md = new MessageDialog (parent, 
@@ -298,63 +459,46 @@ namespace lat
 			return false;
 		}
 
-		private static bool deleteEntry (LdapServer server, string dn)
+		private static bool deleteEntry (Connection conn, string dn)
 		{
 			try {
-				server.Delete (dn);
+				conn.Data.Delete (dn);
 				return true;
 
 			} catch (Exception e) {
 
-				Logger.Log.Debug ("deleteEntry error: {0}", e.Message);
+				Log.Debug ("deleteEntry error: {0}", e.Message);
 				return false;
 			}
 		}
 
-		public static bool DeleteEntry (LdapServer server, Gtk.Window parent, string[] dn)
+		public static bool DeleteEntry (Connection conn, string[] dn)
 		{
 			string msg = String.Format (
 				Mono.Unix.Catalog.GetString (
-				"Are you sure you want to delete:\n\n"));
+				"Are you sure you want to delete the selected entries?"));
 
 			string errorMsg =
 				Mono.Unix.Catalog.GetString (
 				"Unable to delete the following entries:\n");
 			
-			foreach (string n in dn)
-				msg += String.Format ("{0}\n", n);
-
-			if (!Util.AskYesNo (parent, msg))
+			if (!Util.AskYesNo (null, msg))
 				return false;
 
 			bool allGood = true;
 
 			foreach (string d in dn) {
 
-				allGood = deleteEntry (server, d);
+				allGood = deleteEntry (conn, d);
 
 				if (!allGood)
 					errorMsg += d;
 			}
 
-			if (allGood) {
+			if (!allGood) {
 
 				HIGMessageDialog dialog = new HIGMessageDialog (
-					parent,
-					0,
-					Gtk.MessageType.Info,
-					Gtk.ButtonsType.Ok,
-					"Delete entries",
-					Mono.Unix.Catalog.GetString (
-					"Entries successfully deleted."));
-
-				dialog.Run ();
-				dialog.Destroy ();
-
-			} else {
-
-				HIGMessageDialog dialog = new HIGMessageDialog (
-					parent,
+					null,
 					0,
 					Gtk.MessageType.Error,
 					Gtk.ButtonsType.Ok,
@@ -368,7 +512,7 @@ namespace lat
 			return allGood;
 		}
 
-		public static bool DeleteEntry (LdapServer server, Gtk.Window parent, string dn)
+		public static bool DeleteEntry (Connection conn, string dn)
 		{
 			string msg = String.Format ("{0}\n{1}",
 				Mono.Unix.Catalog.GetString (
@@ -377,27 +521,11 @@ namespace lat
 
 			bool retVal = false;
 				
-			if (Util.AskYesNo (parent, msg)) {
+			if (Util.AskYesNo (null, msg)) {
 
 				try {
 
-					server.Delete (dn);
-
-					string resMsg = String.Format (
-						Mono.Unix.Catalog.GetString (
-						"Entry {0} has been deleted."), dn);
-
-					HIGMessageDialog dialog = new HIGMessageDialog (
-						parent,
-						0,
-						Gtk.MessageType.Info,
-						Gtk.ButtonsType.Ok,
-						"Delete entries",
-						resMsg);
-
-					dialog.Run ();
-					dialog.Destroy ();
-
+					conn.Data.Delete (dn);
 					retVal = true;
 
 				} catch (Exception e) {
@@ -409,7 +537,7 @@ namespace lat
 					errorMsg += "\nError: " + e.Message;
 
 					HIGMessageDialog dialog = new HIGMessageDialog (
-						parent,
+						null,
 						0,
 						Gtk.MessageType.Error,
 						Gtk.ButtonsType.Ok,
@@ -424,11 +552,11 @@ namespace lat
 			return retVal;
 		}
 
-		private static void import (LdapServer server, Gtk.Window parent, Uri uri)
+		static void import (Connection conn, Gtk.Window parent, Uri uri)
 		{
 			int numImported = 0;
 
-			LDIF ldif = new LDIF (server);
+			LDIF ldif = new LDIF (conn);
 	
 			numImported = ldif.Import (uri);
 
@@ -464,27 +592,27 @@ namespace lat
 			}
 		}
 		
-		public static void ImportData (LdapServer server, Gtk.Window parent, Uri uri)
+		public static void ImportData (Connection conn, Gtk.Window parent, Uri uri)
 		{
-			import (server, parent, uri);
+			import (conn, parent, uri);
 		}
 
-		public static void ImportData (LdapServer server, Gtk.Window parent, string[] uriList)
+		public static void ImportData (Connection conn, Gtk.Window parent, string[] uriList)
 		{
 			foreach (string u in uriList) {
 				if (!(u.Length > 0))
 					continue;
 
-				import (server, parent, new Uri(u));
+				import (conn, parent, new Uri(u));
 			}
 		}
 
-		public static void ImportData (LdapServer server, Gtk.Window parent, string data)
+		public static void ImportData (Connection conn, Gtk.Window parent, string data)
 		{
 			int numImported = 0;
 			string msg = null;
 
-			LDIF ldif = new LDIF (server);
+			LDIF ldif = new LDIF (conn);
 
 			numImported = ldif.Import (data);
 
@@ -520,9 +648,9 @@ namespace lat
 			}
 		}
 
-		public static void getChildren (LdapServer server, string name, StringBuilder sb)
+		public static void getChildren (Connection conn, string name, StringBuilder sb)
 		{
-			LdapEntry[] children = server.GetEntryChildren (name);
+			LdapEntry[] children = conn.Data.GetEntryChildren (name);
 			
 			if (children == null)
 				return;
@@ -531,37 +659,37 @@ namespace lat
 				LDIF cldif = new LDIF (cle);
 				sb.AppendFormat ("{0}\n", cldif.Export());
 
-				getChildren (server, cle.DN, sb);
+				getChildren (conn, cle.DN, sb);
 			}
 		}
 
-		private static string export (LdapServer server, string dn)
+		static string export (Connection conn, string dn)
 		{
 			StringBuilder data = new StringBuilder();
 
-			LdapEntry le = (LdapEntry) server.GetEntry (dn);
+			LdapEntry le = (LdapEntry) conn.Data.GetEntry (dn);
 			LDIF _ldif = new LDIF (le);
 
 			data.AppendFormat ("{0}\n", _ldif.Export());
 
-			LdapEntry[] children = server.GetEntryChildren (dn);
+			LdapEntry[] children = conn.Data.GetEntryChildren (dn);
 
 			foreach (LdapEntry cle in children) {
 				LDIF cldif = new LDIF (cle);
 				data.AppendFormat ("{0}\n", cldif.Export());
 
-				getChildren (server, cle.DN, data);
+				getChildren (conn, cle.DN, data);
 			}
 
 			return data.ToString ();
 		}
 
-		public static void ExportData (LdapServer server, string dn, out string data)
+		public static void ExportData (Connection conn, string dn, out string data)
 		{
-			data = export (server, dn);
+			data = export (conn, dn);
 		}
 	
-		public static void ExportData (LdapServer server, Gtk.Window parent, string dn)
+		public static void ExportData (Connection conn, Gtk.Window parent, string dn)
 		{
 			FileChooserDialog fcd = new FileChooserDialog (
 				Mono.Unix.Catalog.GetString ("Save LDIF export as"),
@@ -577,7 +705,7 @@ namespace lat
 			ResponseType response = (ResponseType) fcd.Run();
 			if (response == ResponseType.Ok)  {
 
-				string data = export (server, dn);
+				string data = export (conn, dn);
 
 				try {
 
@@ -586,7 +714,21 @@ namespace lat
 						sw.Write (data);
 					}
 
-				} catch {}
+				} catch (Exception e) {
+				
+					Log.Debug (e);
+				
+					HIGMessageDialog dialog = new HIGMessageDialog (
+						parent,
+						0,
+						Gtk.MessageType.Error,
+						Gtk.ButtonsType.Ok,
+						"Export error",
+						e.Message);
+
+					dialog.Run ();
+					dialog.Destroy ();				
+				}
 			} 
 		
 			fcd.Destroy();
