@@ -80,7 +80,7 @@ namespace lat
 		[Glade.Widget] Gtk.Entry attrOrderingEntry;
 		[Glade.Widget] Gtk.Entry attrSubstringEntry;
 		[Glade.Widget] Gtk.Entry attrSyntaxEntry;		
-
+		[Glade.Widget] Gtk.Button searchButton;
 		[Glade.Widget] Gtk.Entry matNameEntry;
 		[Glade.Widget] Gtk.Entry matOIDEntry;
 		[Glade.Widget] Gtk.Entry matSyntaxEntry;
@@ -326,17 +326,11 @@ namespace lat
 
 		void SetBrowserTooltips ()
 		{
-			Tooltips t = new Tooltips ();
-			string tipMsg = null;
+			newMenuToolButton.TooltipText = "Create a new directory entry";
 
-			tipMsg = "Create a new directory entry";
-			newMenuToolButton.SetTooltip (t,  tipMsg, tipMsg);			
+			deleteToolButton.TooltipText = "Delete an entry from the directory";
 
-			tipMsg = "Delete an entry from the directory";
-			deleteToolButton.SetTooltip (t,  tipMsg, tipMsg);			
-
-			tipMsg = "Manage templates for creating new entries";
-			templateToolButton.SetTooltip (t,  tipMsg, tipMsg);			
+			templateToolButton.TooltipText = "Manage templates for creating new entries";
 		}
 
 		void TogglePages (bool pageOneState, bool pageTwoState, bool pageThreeState, bool pageFourState)
@@ -398,23 +392,22 @@ namespace lat
 
 		void SetupToolbar (ViewPlugin vp)
 		{
-			Tooltips t = new Tooltips ();
 			string tipMsg = null;
 
 			tipMsg = String.Format ("Create a new {0}", vp.Name.ToLower());
-			newMenuToolButton.SetTooltip (t,  tipMsg, tipMsg);			
+			newMenuToolButton.TooltipText = tipMsg;
 			newMenuToolButton.Clicked += new EventHandler (viewDataTreeView.OnNewEntryActivate);
 
 			tipMsg = String.Format ("Edit the properties of a {0}", vp.Name.ToLower());
-			propertiesToolButton.SetTooltip (t,  tipMsg, tipMsg);			
+			propertiesToolButton.TooltipText = tipMsg;
 			propertiesToolButton.Clicked += new EventHandler (viewDataTreeView.OnEditActivate);
 			
 			tipMsg = String.Format ("Delete a {0} from the directory", vp.Name.ToLower());
-			deleteToolButton.SetTooltip (t,  tipMsg, tipMsg);			
+			deleteToolButton.TooltipText = tipMsg;
 			deleteToolButton.Clicked += new EventHandler (viewDataTreeView.OnDeleteActivate);
 
 			tipMsg = "Refreshes the data from the server";
-			refreshToolButton.SetTooltip (t,  tipMsg, tipMsg);			
+			refreshToolButton.TooltipText = tipMsg;
 			refreshToolButton.Clicked += new EventHandler (viewDataTreeView.OnRefreshActivate);
 
 			ToggleButtons (true);
@@ -518,16 +511,19 @@ namespace lat
 				objNameTextview.Buffer.Text = tmp;
 
 				tmp = "";
-
-				foreach (string b in sp.Superiors)
+				
+				string[] superiors = sp.Superiors ?? new string[0];
+				foreach (string b in superiors)
 					tmp += String.Format ("{0}\n", b);
 
 				objSuperiorTextview.Buffer.Text = tmp;
-
-				foreach (string c in sp.Required)
+				
+				string[] requireds = sp.Required ?? new string[0];
+				foreach (string c in requireds)
 					objRequiredStore.AppendValues (c);
-
-				foreach (string d in sp.Optional)
+				
+				string[] optionals = sp.Optional ?? new string[0];
+				foreach (string d in optionals)
 					objOptionalStore.AppendValues (d);
 
 				objObsoleteCheckbutton.Active = sp.Obsolete;
@@ -939,9 +935,27 @@ namespace lat
 			string profileName = (string) serverComboBox.Model.GetValue (iter, 0);			
 			Connection conn = Global.Connections [profileName];
 			
-			RfcFilter filter = new RfcFilter (filterEntry.Text);			
-			LdapEntry[] searchResults = conn.Data.Search (searchBaseButton.Label, filter.filterToString());
+			LdapEntry[] searchResults = null;
+			try {
+				RfcFilter filter = new RfcFilter (filterEntry.Text);			
+				searchResults = conn.Data.Search (searchBaseButton.Label, filter.filterToString());
+			}
+			catch(LdapLocalException ex)
+			{
+				HIGMessageDialog dialog = new HIGMessageDialog (
+					mainWindow,
+					0,
+					Gtk.MessageType.Error,
+					Gtk.ButtonsType.Ok,
+					"Search error",
+					string.Format("{0}.\n{1}", ex.Message, ex.LdapErrorMessage));
 
+				dialog.Run ();
+				dialog.Destroy ();
+				
+				return;
+			}
+			
 			if (searchResults == null) {
 				HIGMessageDialog dialog = new HIGMessageDialog (
 					mainWindow,
@@ -980,8 +994,10 @@ namespace lat
 				scd.Title = Mono.Unix.Catalog.GetString ("Select search base");
 				scd.Run ();
 
-				if (!scd.DN.Equals ("") && !scd.DN.Equals (conn.Settings.Host))
+				if (!scd.DN.Equals ("") && !scd.DN.Equals (conn.Settings.Host)) {
 					searchBaseButton.Label = scd.DN;
+					searchButton.Sensitive = true;
+				}
 					
 			} catch {}
 		}
@@ -1318,6 +1334,7 @@ namespace lat
 				valuesScrolledWindow.AddWithViewport (serverInfoView);
 				valuesScrolledWindow.ShowAll ();
 
+				ToggleButtons (false);
 				UpdateStatusBar ();
 				
 				return;
